@@ -1,5 +1,6 @@
 from ._director import Director
 from ._reporter import Reporter
-from .reporters import RichReporter, SilentReporter
+from .rich import RichReporter
+from .silent import SilentReporter
 
 __all__ = ("Director", "Reporter", "RichReporter", "SilentReporter",)
